@@ -1,18 +1,18 @@
 /*
   libuta - a C++ widget library based on SDL (Simple Direct Layer)
-  Copyright (C) 1999  Karsten Laux
+  Copyright (C) 1999-2002  Karsten Laux
 
   This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
+  modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+  version 2.1 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+  Lesser General Public License for more details.
   
-  You should have received a copy of the GNU Library General Public
+  You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA  02111-1307, SA.
@@ -55,16 +55,17 @@ class Color
   ///order high to low: ARGB
   Color(const long unsigned int& col_);
   
-  ///
-  ~Color() {;}
-
   ///this only compares colors (without alpha channel !)
   friend bool operator==(const Color &c1, const Color &c2)
   {
     return c1.r==c2.r && c1.g==c2.g && c1.b==c2.b;
   }
+  friend bool operator!=(const Color &c1, const Color &c2)
+  {
+    return c1.r!=c2.r || c1.g!=c2.g || c1.b!=c2.b;
+  }
   ///
-  friend ostream& operator<<(ostream& s, const Color& c);   
+  friend std::ostream& operator<<(std::ostream& s, const Color& c);   
 
   ///
   unsigned char r;
