@@ -1,18 +1,18 @@
 /*
   libuta - a C++ widget library based on SDL (Simple Direct Layer)
-  Copyright (C) 1999  Karsten Laux
+  Copyright (C) 1999-2002  Karsten Laux
 
   This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
+  modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
+  version 2.1 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
+  Lesser General Public License for more details.
   
-  You should have received a copy of the GNU Library General Public
+  You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA  02111-1307, SA.
@@ -26,14 +26,14 @@
 namespace uta {
 
 ///
-class MessageBox : public DialogBox
+class MessageBox : public uDialogBox
 {
  
  public:
   ///
-  MessageBox(const string& title, const string& msg);
+  MessageBox(const std::string& title, const std::string& msg);
   ///
-  MessageBox(const string& msg);
+  MessageBox(const std::string& msg);
   ///
   virtual ~MessageBox();
 
